.. _tensor-tensor:

Tensor
======

.. module:: sympy.tensor.tensor

.. autoclass:: TIDS
   :members:

.. autoclass:: VTIDS
   :members:

.. autoclass:: _TensorManager
   :members:

.. autoclass:: TensorIndexType
   :members:

.. autoclass:: TensorIndex
   :members:

.. autofunction:: tensor_indices

.. autoclass:: TensorSymmetry
   :members:

.. autoclass:: TensorType
   :members:

.. autoclass:: TensorHead
   :members:

.. autoclass:: TensExpr
   :members:

.. autoclass:: TensAdd
   :members:

.. autoclass:: TensMul
   :members:

.. autofunction:: canon_bp

.. autofunction:: tensor_mul

.. autofunction:: riemann_cyclic_replace

.. autofunction:: riemann_cyclic

